@@ -1,14 +1,13 @@
 /*
  * This file is part of hildon-base-lib
  *
- * Copyright (C) 2005 Nokia Corporation.
+ * Copyright (C) 2005, 2006 Nokia Corporation.
  *
- * Contact: Luc Pionchon <luc.pionchon@nokia.com>
+ * Contact: Karoliina Salminen <karoliina.t.salminen@nokia.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
+ * version 2.1 as published by the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -189,7 +188,12 @@ hildon_return_t hildon_dnotify_remove_cb(char * path)
 	gboolean shared_path = FALSE;
 
 	if( (path == NULL) || (dir_funcs == NULL) || (dir_src == NULL) )
+	{
+	 	if (shared_path)
+		  	free (path);
 		return HILDON_ERR;
+	}
+
 	dir = _dir_map;
 	prev = NULL;
 	while(dir!=NULL) {
